# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file

import builtins as _builtins, typing as _typing

import grpc as _grpc
from grpc import aio as _grpc_aio

from .domain_connectivity_pb2 import ConnectDomainRequest, ConnectDomainResponse, DisconnectDomainRequest, DisconnectDomainResponse, GetDomainIdRequest, GetDomainIdResponse, ListConfiguredDomainsRequest, ListConfiguredDomainsResponse, ListConnectedDomainsRequest, ListConnectedDomainsResponse, ModifyDomainRequest, ModifyDomainResponse, ReconnectDomainsRequest, ReconnectDomainsResponse, RegisterDomainRequest, RegisterDomainResponse

__all__ = [
    "DomainConnectivityServiceStub",
]


# noinspection PyPep8Naming,DuplicatedCode
class DomainConnectivityServiceStub:
    @classmethod  # type: ignore
    @_typing.overload
    def __new__(cls, channel: _grpc.Channel) -> _DomainConnectivityServiceBlockingStub: ...  # type: ignore
    @classmethod  # type: ignore
    @_typing.overload
    def __new__(cls, channel: _grpc_aio.Channel) -> _DomainConnectivityServiceAsyncStub: ...  # type: ignore
    def ReconnectDomains(self, __1: ReconnectDomainsRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[ReconnectDomainsResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, ReconnectDomainsResponse]]: ...
    def RegisterDomain(self, __1: RegisterDomainRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[RegisterDomainResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, RegisterDomainResponse]]: ...
    def ModifyDomain(self, __1: ModifyDomainRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[ModifyDomainResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, ModifyDomainResponse]]: ...
    def ConnectDomain(self, __1: ConnectDomainRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[ConnectDomainResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, ConnectDomainResponse]]: ...
    def DisconnectDomain(self, __1: DisconnectDomainRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[DisconnectDomainResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, DisconnectDomainResponse]]: ...
    def ListConnectedDomains(self, __1: ListConnectedDomainsRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[ListConnectedDomainsResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, ListConnectedDomainsResponse]]: ...
    def ListConfiguredDomains(self, __1: ListConfiguredDomainsRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[ListConfiguredDomainsResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, ListConfiguredDomainsResponse]]: ...
    def GetDomainId(self, __1: GetDomainIdRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[GetDomainIdResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, GetDomainIdResponse]]: ...

# noinspection PyPep8Naming,DuplicatedCode
class _DomainConnectivityServiceBlockingStub(DomainConnectivityServiceStub):
    def ReconnectDomains(self, __1: ReconnectDomainsRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ReconnectDomainsResponse: ...
    def RegisterDomain(self, __1: RegisterDomainRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> RegisterDomainResponse: ...
    def ModifyDomain(self, __1: ModifyDomainRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ModifyDomainResponse: ...
    def ConnectDomain(self, __1: ConnectDomainRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ConnectDomainResponse: ...
    def DisconnectDomain(self, __1: DisconnectDomainRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> DisconnectDomainResponse: ...
    def ListConnectedDomains(self, __1: ListConnectedDomainsRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListConnectedDomainsResponse: ...
    def ListConfiguredDomains(self, __1: ListConfiguredDomainsRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListConfiguredDomainsResponse: ...
    def GetDomainId(self, __1: GetDomainIdRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> GetDomainIdResponse: ...

# noinspection PyPep8Naming,DuplicatedCode
class _DomainConnectivityServiceAsyncStub(DomainConnectivityServiceStub):
    def ReconnectDomains(self, __1: ReconnectDomainsRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, ReconnectDomainsResponse]: ...  # type: ignore
    def RegisterDomain(self, __1: RegisterDomainRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, RegisterDomainResponse]: ...  # type: ignore
    def ModifyDomain(self, __1: ModifyDomainRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, ModifyDomainResponse]: ...  # type: ignore
    def ConnectDomain(self, __1: ConnectDomainRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, ConnectDomainResponse]: ...  # type: ignore
    def DisconnectDomain(self, __1: DisconnectDomainRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, DisconnectDomainResponse]: ...  # type: ignore
    def ListConnectedDomains(self, __1: ListConnectedDomainsRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, ListConnectedDomainsResponse]: ...  # type: ignore
    def ListConfiguredDomains(self, __1: ListConfiguredDomainsRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, ListConfiguredDomainsResponse]: ...  # type: ignore
    def GetDomainId(self, __1: GetDomainIdRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, GetDomainIdResponse]: ...  # type: ignore



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class AcsCommitment(_message.Message):
    __slots__ = ("domain_id", "sending_participant_uid", "counter_participant_uid", "from_exclusive", "to_inclusive", "commitment")
    DOMAIN_ID_FIELD_NUMBER: _ClassVar[int]
    SENDING_PARTICIPANT_UID_FIELD_NUMBER: _ClassVar[int]
    COUNTER_PARTICIPANT_UID_FIELD_NUMBER: _ClassVar[int]
    FROM_EXCLUSIVE_FIELD_NUMBER: _ClassVar[int]
    TO_INCLUSIVE_FIELD_NUMBER: _ClassVar[int]
    COMMITMENT_FIELD_NUMBER: _ClassVar[int]
    domain_id: str
    sending_participant_uid: str
    counter_participant_uid: str
    from_exclusive: int
    to_inclusive: int
    commitment: bytes
    def __init__(self, domain_id: _Optional[str] = ..., sending_participant_uid: _Optional[str] = ..., counter_participant_uid: _Optional[str] = ..., from_exclusive: _Optional[int] = ..., to_inclusive: _Optional[int] = ..., commitment: _Optional[bytes] = ...) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from . import service_agreement_pb2 as _service_agreement_pb2
from ....protocol.v0 import sequencing_pb2 as _sequencing_pb2
from ....protocol.v1 import sequencing_pb2 as _sequencing_pb2_1
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SequencerConnect(_message.Message):
    __slots__ = ()
    class GetDomainId(_message.Message):
        __slots__ = ()
        class Request(_message.Message):
            __slots__ = ()
            def __init__(self) -> None: ...
        class Response(_message.Message):
            __slots__ = ("domain_id", "sequencer_id")
            DOMAIN_ID_FIELD_NUMBER: _ClassVar[int]
            SEQUENCER_ID_FIELD_NUMBER: _ClassVar[int]
            domain_id: str
            sequencer_id: str
            def __init__(self, domain_id: _Optional[str] = ..., sequencer_id: _Optional[str] = ...) -> None: ...
        def __init__(self) -> None: ...
    class GetDomainParameters(_message.Message):
        __slots__ = ()
        class Request(_message.Message):
            __slots__ = ()
            def __init__(self) -> None: ...
        class Response(_message.Message):
            __slots__ = ("parameters_v0", "parameters_v1")
            PARAMETERS_V0_FIELD_NUMBER: _ClassVar[int]
            PARAMETERS_V1_FIELD_NUMBER: _ClassVar[int]
            parameters_v0: _sequencing_pb2.StaticDomainParameters
            parameters_v1: _sequencing_pb2_1.StaticDomainParameters
            def __init__(self, parameters_v0: _Optional[_Union[_sequencing_pb2.StaticDomainParameters, _Mapping]] = ..., parameters_v1: _Optional[_Union[_sequencing_pb2_1.StaticDomainParameters, _Mapping]] = ...) -> None: ...
        def __init__(self) -> None: ...
    class VerifyActive(_message.Message):
        __slots__ = ()
        class Request(_message.Message):
            __slots__ = ()
            def __init__(self) -> None: ...
        class Response(_message.Message):
            __slots__ = ("success", "failure")
            SUCCESS_FIELD_NUMBER: _ClassVar[int]
            FAILURE_FIELD_NUMBER: _ClassVar[int]
            success: SequencerConnect.VerifyActive.Success
            failure: SequencerConnect.VerifyActive.Failure
            def __init__(self, success: _Optional[_Union[SequencerConnect.VerifyActive.Success, _Mapping]] = ..., failure: _Optional[_Union[SequencerConnect.VerifyActive.Failure, _Mapping]] = ...) -> None: ...
        class Success(_message.Message):
            __slots__ = ("is_active",)
            IS_ACTIVE_FIELD_NUMBER: _ClassVar[int]
            is_active: bool
            def __init__(self, is_active: bool = ...) -> None: ...
        class Failure(_message.Message):
            __slots__ = ("reason",)
            REASON_FIELD_NUMBER: _ClassVar[int]
            reason: str
            def __init__(self, reason: _Optional[str] = ...) -> None: ...
        def __init__(self) -> None: ...
    def __init__(self) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/admin/participant/v30/traffic_control_service.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/admin/participant/v30/traffic_control_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nKcom/digitalasset/canton/admin/participant/v30/traffic_control_service.proto\x12-com.digitalasset.canton.admin.participant.v30\x1a\x1egoogle/protobuf/wrappers.proto\"9\n\x1aTrafficControlStateRequest\x12\x1b\n\tdomain_id\x18\x01 \x01(\tR\x08\x64omainId\"\x7f\n\x1bTrafficControlStateResponse\x12`\n\rtraffic_state\x18\x01 \x01(\x0b\x32;.com.digitalasset.canton.admin.participant.v30.TrafficStateR\x0ctrafficState\"\xb4\x02\n\x0cTrafficState\x12\x36\n\x17\x65xtra_traffic_purchased\x18\x01 \x01(\x03R\x15\x65xtraTrafficPurchased\x12\x34\n\x16\x65xtra_traffic_consumed\x18\x02 \x01(\x03R\x14\x65xtraTrafficConsumed\x12\x34\n\x16\x62\x61se_traffic_remainder\x18\x03 \x01(\x03R\x14\x62\x61seTrafficRemainder\x12,\n\x12last_consumed_cost\x18\x04 \x01(\x04R\x10lastConsumedCost\x12\x1c\n\ttimestamp\x18\x05 \x01(\x03R\ttimestamp\x12\x34\n\x06serial\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x06serial2\xc6\x01\n\x15TrafficControlService\x12\xac\x01\n\x13TrafficControlState\x12I.com.digitalasset.canton.admin.participant.v30.TrafficControlStateRequest\x1aJ.com.digitalasset.canton.admin.participant.v30.TrafficControlStateResponseB^Z\\github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/admin/participant/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.admin.participant.v30.traffic_control_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\\github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/admin/participant/v30'
  _globals['_TRAFFICCONTROLSTATEREQUEST']._serialized_start=158
  _globals['_TRAFFICCONTROLSTATEREQUEST']._serialized_end=215
  _globals['_TRAFFICCONTROLSTATERESPONSE']._serialized_start=217
  _globals['_TRAFFICCONTROLSTATERESPONSE']._serialized_end=344
  _globals['_TRAFFICSTATE']._serialized_start=347
  _globals['_TRAFFICSTATE']._serialized_end=655
  _globals['_TRAFFICCONTROLSERVICE']._serialized_start=658
  _globals['_TRAFFICCONTROLSERVICE']._serialized_end=856
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from google.protobuf import empty_pb2 as _empty_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class ResourceLimits(_message.Message):
    __slots__ = ("max_dirty_requests", "max_rate", "max_burst_factor")
    MAX_DIRTY_REQUESTS_FIELD_NUMBER: _ClassVar[int]
    MAX_RATE_FIELD_NUMBER: _ClassVar[int]
    MAX_BURST_FACTOR_FIELD_NUMBER: _ClassVar[int]
    max_dirty_requests: int
    max_rate: int
    max_burst_factor: float
    def __init__(self, max_dirty_requests: _Optional[int] = ..., max_rate: _Optional[int] = ..., max_burst_factor: _Optional[float] = ...) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/participant/protocol/v0/submission_tracking.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/participant/protocol/v0/submission_tracking.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import ledger_sync_event_pb2 as com_dot_digitalasset_dot_canton_dot_participant_dot_protocol_dot_v0_dot_ledger__sync__event__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nIcom/digitalasset/canton/participant/protocol/v0/submission_tracking.proto\x12/com.digitalasset.canton.participant.protocol.v0\x1aGcom/digitalasset/canton/participant/protocol/v0/ledger_sync_event.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1egoogle/protobuf/wrappers.proto\"\x9c\x01\n\x16SubmissionTrackingData\x12v\n\x0btransaction\x18\x01 \x01(\x0b\x32R.com.digitalasset.canton.participant.protocol.v0.TransactionSubmissionTrackingDataH\x00R\x0btransactionB\n\n\x08tracking\"\xc2\x04\n!TransactionSubmissionTrackingData\x12h\n\x0f\x63ompletion_info\x18\x01 \x01(\x0b\x32?.com.digitalasset.canton.participant.protocol.v0.CompletionInfoR\x0e\x63ompletionInfo\x12\x8a\x01\n\x0frejection_cause\x18\x02 \x01(\x0b\x32\x61.com.digitalasset.canton.participant.protocol.v0.TransactionSubmissionTrackingData.RejectionCauseR\x0erejectionCause\x12\x39\n\tdomain_id\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x08\x64omainId\x1a\xea\x01\n\x0eRejectionCause\x12\x32\n\x07timeout\x18\x01 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00R\x07timeout\x12\x9a\x01\n\x19rejection_reason_template\x18\x02 \x01(\x0b\x32\\.com.digitalasset.canton.participant.protocol.v0.CommandRejected.GrpcRejectionReasonTemplateH\x00R\x17rejectionReasonTemplateB\x07\n\x05\x63\x61useB`Z^github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/participant/protocol/v0b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.participant.protocol.v0.submission_tracking_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z^github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/participant/protocol/v0'
  _globals['_SUBMISSIONTRACKINGDATA']._serialized_start=261
  _globals['_SUBMISSIONTRACKINGDATA']._serialized_end=417
  _globals['_TRANSACTIONSUBMISSIONTRACKINGDATA']._serialized_start=420
  _globals['_TRANSACTIONSUBMISSIONTRACKINGDATA']._serialized_end=998
  _globals['_TRANSACTIONSUBMISSIONTRACKINGDATA_REJECTIONCAUSE']._serialized_start=764
  _globals['_TRANSACTIONSUBMISSIONTRACKINGDATA_REJECTIONCAUSE']._serialized_end=998
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from . import enterprise_sequencer_connection_service_pb2 as com_dot_digitalasset_dot_canton_dot_domain_dot_admin_dot_v0_dot_enterprise__sequencer__connection__service__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2

GRPC_GENERATED_VERSION = '1.67.1'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in com/digitalasset/canton/domain/admin/v0/enterprise_sequencer_connection_service_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class EnterpriseSequencerConnectionServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetConnection = channel.unary_unary(
                '/com.digitalasset.canton.domain.admin.v0.EnterpriseSequencerConnectionService/GetConnection',
                request_serializer=com_dot_digitalasset_dot_canton_dot_domain_dot_admin_dot_v0_dot_enterprise__sequencer__connection__service__pb2.GetConnectionRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_domain_dot_admin_dot_v0_dot_enterprise__sequencer__connection__service__pb2.GetConnectionResponse.FromString,
                _registered_method=True)
        self.SetConnection = channel.unary_unary(
                '/com.digitalasset.canton.domain.admin.v0.EnterpriseSequencerConnectionService/SetConnection',
                request_serializer=com_dot_digitalasset_dot_canton_dot_domain_dot_admin_dot_v0_dot_enterprise__sequencer__connection__service__pb2.SetConnectionRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                _registered_method=True)


class EnterpriseSequencerConnectionServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetConnection(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetConnection(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_EnterpriseSequencerConnectionServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetConnection': grpc.unary_unary_rpc_method_handler(
                    servicer.GetConnection,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_domain_dot_admin_dot_v0_dot_enterprise__sequencer__connection__service__pb2.GetConnectionRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_domain_dot_admin_dot_v0_dot_enterprise__sequencer__connection__service__pb2.GetConnectionResponse.SerializeToString,
            ),
            'SetConnection': grpc.unary_unary_rpc_method_handler(
                    servicer.SetConnection,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_domain_dot_admin_dot_v0_dot_enterprise__sequencer__connection__service__pb2.SetConnectionRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'com.digitalasset.canton.domain.admin.v0.EnterpriseSequencerConnectionService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('com.digitalasset.canton.domain.admin.v0.EnterpriseSequencerConnectionService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class EnterpriseSequencerConnectionService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetConnection(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.domain.admin.v0.EnterpriseSequencerConnectionService/GetConnection',
            com_dot_digitalasset_dot_canton_dot_domain_dot_admin_dot_v0_dot_enterprise__sequencer__connection__service__pb2.GetConnectionRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_domain_dot_admin_dot_v0_dot_enterprise__sequencer__connection__service__pb2.GetConnectionResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SetConnection(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.domain.admin.v0.EnterpriseSequencerConnectionService/SetConnection',
            com_dot_digitalasset_dot_canton_dot_domain_dot_admin_dot_v0_dot_enterprise__sequencer__connection__service__pb2.SetConnectionRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/version/v1/untyped_versioned_message.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/version/v1/untyped_versioned_message.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nBcom/digitalasset/canton/version/v1/untyped_versioned_message.proto\x12\"com.digitalasset.canton.version.v1\"T\n\x17UntypedVersionedMessage\x12\x14\n\x04\x64\x61ta\x18\x01 \x01(\x0cH\x00R\x04\x64\x61ta\x12\x18\n\x07version\x18\x02 \x01(\x05R\x07versionB\t\n\x07wrapperBSZQgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/version/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.version.v1.untyped_versioned_message_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZQgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/version/v1'
  _globals['_UNTYPEDVERSIONEDMESSAGE']._serialized_start=106
  _globals['_UNTYPEDVERSIONEDMESSAGE']._serialized_end=190
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file

from .domain_connectivity_pb2 import AcceptAgreementRequest, AcceptAgreementResponse, Agreement, ConnectDomainRequest, ConnectDomainResponse, DisconnectDomainRequest, DisconnectDomainResponse, DomainConnectionConfig, GetAgreementRequest, GetAgreementResponse, GetDomainIdRequest, GetDomainIdResponse, ListConfiguredDomainsRequest, ListConfiguredDomainsResponse, ListConnectedDomainsRequest, ListConnectedDomainsResponse, ModifyDomainRequest, ModifyDomainResponse, ReconnectDomainsRequest, ReconnectDomainsResponse, RegisterDomainRequest, RegisterDomainResponse
from .domain_connectivity_pb2_grpc import DomainConnectivityServiceStub
from .enterprise_participant_replication_service_pb2 import SetPassive
from .enterprise_participant_replication_service_pb2_grpc import EnterpriseParticipantReplicationServiceStub
from .inspection_service_pb2 import CountInFlight, LookupContractDomain, LookupOffsetByIndex, LookupOffsetByTime, LookupTransactionDomain
from .inspection_service_pb2_grpc import InspectionServiceStub
from .package_service_pb2 import DarDescription, GetDarRequest, GetDarResponse, ListDarContentsRequest, ListDarContentsResponse, ListDarsRequest, ListDarsResponse, ListPackageContentsRequest, ListPackageContentsResponse, ListPackagesRequest, ListPackagesResponse, ModuleDescription, PackageDescription, RemoveDarRequest, RemoveDarResponse, RemovePackageRequest, RemovePackageResponse, UnvetDarRequest, UnvetDarResponse, UploadDarRequest, UploadDarResponse, ValidateDarRequest, ValidateDarResponse, VetDarRequest, VetDarResponse
from .package_service_pb2_grpc import PackageServiceStub
from .participant_repair_service_pb2 import AcsSnapshotChunk, ActiveContract, DownloadRequest, ExportAcsRequest, ExportAcsResponse, IgnoreEventsRequest, IgnoreEventsResponse, ImportAcsRequest, ImportAcsResponse, MigrateDomainRequest, MigrateDomainResponse, PurgeContractsRequest, PurgeContractsResponse, PurgeDeactivatedDomainRequest, PurgeDeactivatedDomainResponse, UnignoreEventsRequest, UnignoreEventsResponse, UploadRequest, UploadResponse
from .participant_repair_service_pb2_grpc import ParticipantRepairServiceStub
from .party_name_management_pb2 import SetPartyDisplayNameRequest, SetPartyDisplayNameResponse
from .party_name_management_pb2_grpc import PartyNameManagementServiceStub
from .ping_pong_service_pb2 import PingFailure, PingRequest, PingResponse, PingSuccess
from .ping_pong_service_pb2_grpc import PingServiceStub
from .pruning_service_pb2 import GetSafePruningOffsetRequest, GetSafePruningOffsetResponse, PruneRequest, PruneResponse
from .pruning_service_pb2_grpc import PruningServiceStub
from .resource_management_service_pb2 import ResourceLimits
from .resource_management_service_pb2_grpc import ResourceManagementServiceStub
from .transfer_service_pb2 import AdminTransferInRequest, AdminTransferInResponse, AdminTransferOutRequest, AdminTransferOutResponse, AdminTransferSearchQuery, AdminTransferSearchResponse
from .transfer_service_pb2_grpc import TransferServiceStub

__all__ = [
    "AcceptAgreementRequest",
    "AcceptAgreementResponse",
    "AcsSnapshotChunk",
    "ActiveContract",
    "AdminTransferInRequest",
    "AdminTransferInResponse",
    "AdminTransferOutRequest",
    "AdminTransferOutResponse",
    "AdminTransferSearchQuery",
    "AdminTransferSearchResponse",
    "Agreement",
    "ConnectDomainRequest",
    "ConnectDomainResponse",
    "CountInFlight",
    "DarDescription",
    "DisconnectDomainRequest",
    "DisconnectDomainResponse",
    "DomainConnectionConfig",
    "DomainConnectivityServiceStub",
    "DownloadRequest",
    "EnterpriseParticipantReplicationServiceStub",
    "ExportAcsRequest",
    "ExportAcsResponse",
    "GetAgreementRequest",
    "GetAgreementResponse",
    "GetDarRequest",
    "GetDarResponse",
    "GetDomainIdRequest",
    "GetDomainIdResponse",
    "GetSafePruningOffsetRequest",
    "GetSafePruningOffsetResponse",
    "IgnoreEventsRequest",
    "IgnoreEventsResponse",
    "ImportAcsRequest",
    "ImportAcsResponse",
    "InspectionServiceStub",
    "ListConfiguredDomainsRequest",
    "ListConfiguredDomainsResponse",
    "ListConnectedDomainsRequest",
    "ListConnectedDomainsResponse",
    "ListDarContentsRequest",
    "ListDarContentsResponse",
    "ListDarsRequest",
    "ListDarsResponse",
    "ListPackageContentsRequest",
    "ListPackageContentsResponse",
    "ListPackagesRequest",
    "ListPackagesResponse",
    "LookupContractDomain",
    "LookupOffsetByIndex",
    "LookupOffsetByTime",
    "LookupTransactionDomain",
    "MigrateDomainRequest",
    "MigrateDomainResponse",
    "ModifyDomainRequest",
    "ModifyDomainResponse",
    "ModuleDescription",
    "PackageDescription",
    "PackageServiceStub",
    "ParticipantRepairServiceStub",
    "PartyNameManagementServiceStub",
    "PingFailure",
    "PingRequest",
    "PingResponse",
    "PingServiceStub",
    "PingSuccess",
    "PruneRequest",
    "PruneResponse",
    "PruningServiceStub",
    "PurgeContractsRequest",
    "PurgeContractsResponse",
    "PurgeDeactivatedDomainRequest",
    "PurgeDeactivatedDomainResponse",
    "ReconnectDomainsRequest",
    "ReconnectDomainsResponse",
    "RegisterDomainRequest",
    "RegisterDomainResponse",
    "RemoveDarRequest",
    "RemoveDarResponse",
    "RemovePackageRequest",
    "RemovePackageResponse",
    "ResourceLimits",
    "ResourceManagementServiceStub",
    "SetPartyDisplayNameRequest",
    "SetPartyDisplayNameResponse",
    "SetPassive",
    "TransferServiceStub",
    "UnignoreEventsRequest",
    "UnignoreEventsResponse",
    "UnvetDarRequest",
    "UnvetDarResponse",
    "UploadDarRequest",
    "UploadDarResponse",
    "UploadRequest",
    "UploadResponse",
    "ValidateDarRequest",
    "ValidateDarResponse",
    "VetDarRequest",
    "VetDarResponse",
]



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/protocol/v30/participant_transfer.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/protocol/v30/participant_transfer.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ...crypto.v30 import crypto_pb2 as com_dot_digitalasset_dot_canton_dot_crypto_dot_v30_dot_crypto__pb2
from . import common_stable_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v30_dot_common__stable__pb2
from . import merkle_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v30_dot_merkle__pb2
from ...time.v30 import time_proof_pb2 as com_dot_digitalasset_dot_canton_dot_time_dot_v30_dot_time__proof__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n?com/digitalasset/canton/protocol/v30/participant_transfer.proto\x12$com.digitalasset.canton.protocol.v30\x1a/com/digitalasset/canton/crypto/v30/crypto.proto\x1a\x38\x63om/digitalasset/canton/protocol/v30/common_stable.proto\x1a\x31\x63om/digitalasset/canton/protocol/v30/merkle.proto\x1a\x31\x63om/digitalasset/canton/time/v30/time_proof.proto\"O\n\nTransferId\x12#\n\rsource_domain\x18\x01 \x01(\tR\x0csourceDomain\x12\x1c\n\ttimestamp\x18\x02 \x01(\x03R\ttimestamp\"\xfb\x02\n\x15TransferOutCommonData\x12<\n\x04salt\x18\x01 \x01(\x0b\x32(.com.digitalasset.canton.crypto.v30.SaltR\x04salt\x12#\n\rsource_domain\x18\x02 \x01(\tR\x0csourceDomain\x12\"\n\x0cstakeholders\x18\x03 \x03(\tR\x0cstakeholders\x12#\n\radmin_parties\x18\x04 \x03(\tR\x0c\x61\x64minParties\x12\x12\n\x04uuid\x18\x05 \x01(\tR\x04uuid\x12\x32\n\x15source_mediator_group\x18\x06 \x01(\x05R\x13sourceMediatorGroup\x12n\n\x12submitter_metadata\x18\x07 \x01(\x0b\x32?.com.digitalasset.canton.protocol.v30.TransferSubmitterMetadataR\x11submitterMetadata\"\x93\x01\n\x10TransferViewTree\x12\x1f\n\x0b\x63ommon_data\x18\x01 \x01(\x0cR\ncommonData\x12^\n\x10participant_data\x18\x02 \x01(\x0b\x32\x33.com.digitalasset.canton.protocol.v30.BlindableNodeR\x0fparticipantData\"\xe0\x01\n\x19TransferInMediatorMessage\x12J\n\x04tree\x18\x01 \x01(\x0b\x32\x36.com.digitalasset.canton.protocol.v30.TransferViewTreeR\x04tree\x12w\n submitting_participant_signature\x18\x02 \x01(\x0b\x32-.com.digitalasset.canton.crypto.v30.SignatureR\x1esubmittingParticipantSignature\"\xe1\x01\n\x1aTransferOutMediatorMessage\x12J\n\x04tree\x18\x01 \x01(\x0b\x32\x36.com.digitalasset.canton.protocol.v30.TransferViewTreeR\x04tree\x12w\n submitting_participant_signature\x18\x02 \x01(\x0b\x32-.com.digitalasset.canton.crypto.v30.SignatureR\x1esubmittingParticipantSignature\"\xd5\x02\n\x14TransferInCommonData\x12<\n\x04salt\x18\x01 \x01(\x0b\x32(.com.digitalasset.canton.crypto.v30.SaltR\x04salt\x12#\n\rtarget_domain\x18\x02 \x01(\tR\x0ctargetDomain\x12\"\n\x0cstakeholders\x18\x03 \x03(\tR\x0cstakeholders\x12\x12\n\x04uuid\x18\x04 \x01(\tR\x04uuid\x12\x32\n\x15target_mediator_group\x18\x06 \x01(\x05R\x13targetMediatorGroup\x12n\n\x12submitter_metadata\x18\x07 \x01(\x0b\x32?.com.digitalasset.canton.protocol.v30.TransferSubmitterMetadataR\x11submitterMetadata\"\x83\x02\n\x19TransferSubmitterMetadata\x12\x1c\n\tsubmitter\x18\x01 \x01(\tR\tsubmitter\x12<\n\x1asubmitting_participant_uid\x18\x02 \x01(\tR\x18submittingParticipantUid\x12\x1d\n\ncommand_id\x18\x03 \x01(\tR\tcommandId\x12#\n\rsubmission_id\x18\x04 \x01(\tR\x0csubmissionId\x12%\n\x0e\x61pplication_id\x18\x05 \x01(\tR\rapplicationId\x12\x1f\n\x0bworkflow_id\x18\x06 \x01(\tR\nworkflowId\"\xc0\x03\n\x0fTransferOutView\x12<\n\x04salt\x18\x01 \x01(\x0b\x32(.com.digitalasset.canton.crypto.v30.SaltR\x04salt\x12#\n\rtarget_domain\x18\x03 \x01(\tR\x0ctargetDomain\x12W\n\x11target_time_proof\x18\x04 \x01(\x0b\x32+.com.digitalasset.canton.time.v30.TimeProofR\x0ftargetTimeProof\x12\x36\n\x17target_protocol_version\x18\x05 \x01(\x05R\x15targetProtocolVersion\x12)\n\x10transfer_counter\x18\x0b \x01(\x03R\x0ftransferCounter\x12\x36\n\x17\x63reating_transaction_id\x18\x0c \x01(\x0cR\x15\x63reatingTransactionId\x12V\n\x08\x63ontract\x18\r \x01(\x0b\x32:.com.digitalasset.canton.protocol.v30.SerializableContractR\x08\x63ontract\"\xfc\x02\n\x0eTransferInView\x12<\n\x04salt\x18\x01 \x01(\x0b\x32(.com.digitalasset.canton.crypto.v30.SaltR\x04salt\x12V\n\x08\x63ontract\x18\x03 \x01(\x0b\x32:.com.digitalasset.canton.protocol.v30.SerializableContractR\x08\x63ontract\x12\x39\n\x19transfer_out_result_event\x18\x04 \x01(\x0cR\x16transferOutResultEvent\x12\x36\n\x17\x63reating_transaction_id\x18\x05 \x01(\x0cR\x15\x63reatingTransactionId\x12\x36\n\x17source_protocol_version\x18\x06 \x01(\x05R\x15sourceProtocolVersion\x12)\n\x10transfer_counter\x18\x0c \x01(\x03R\x0ftransferCounterBUZSgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/protocol/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.protocol.v30.participant_transfer_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZSgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/protocol/v30'
  _globals['_TRANSFERID']._serialized_start=314
  _globals['_TRANSFERID']._serialized_end=393
  _globals['_TRANSFEROUTCOMMONDATA']._serialized_start=396
  _globals['_TRANSFEROUTCOMMONDATA']._serialized_end=775
  _globals['_TRANSFERVIEWTREE']._serialized_start=778
  _globals['_TRANSFERVIEWTREE']._serialized_end=925
  _globals['_TRANSFERINMEDIATORMESSAGE']._serialized_start=928
  _globals['_TRANSFERINMEDIATORMESSAGE']._serialized_end=1152
  _globals['_TRANSFEROUTMEDIATORMESSAGE']._serialized_start=1155
  _globals['_TRANSFEROUTMEDIATORMESSAGE']._serialized_end=1380
  _globals['_TRANSFERINCOMMONDATA']._serialized_start=1383
  _globals['_TRANSFERINCOMMONDATA']._serialized_end=1724
  _globals['_TRANSFERSUBMITTERMETADATA']._serialized_start=1727
  _globals['_TRANSFERSUBMITTERMETADATA']._serialized_end=1986
  _globals['_TRANSFEROUTVIEW']._serialized_start=1989
  _globals['_TRANSFEROUTVIEW']._serialized_end=2437
  _globals['_TRANSFERINVIEW']._serialized_start=2440
  _globals['_TRANSFERINVIEW']._serialized_end=2820
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/protocol/v2/mediator.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/protocol/v2/mediator.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ..v0 import common_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v0_dot_common__pb2
from ..v1 import mediator_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v1_dot_mediator__pb2
from ..v1 import mediator_response_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v1_dot_mediator__response__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.rpc import status_pb2 as google_dot_rpc_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2com/digitalasset/canton/protocol/v2/mediator.proto\x12#com.digitalasset.canton.protocol.v2\x1a\x30\x63om/digitalasset/canton/protocol/v0/common.proto\x1a\x32\x63om/digitalasset/canton/protocol/v1/mediator.proto\x1a;com/digitalasset/canton/protocol/v1/mediator_response.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x17google/rpc/status.proto\"\xd7\x01\n\x18TransactionResultMessage\x12\x39\n\nrequest_id\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\trequestId\x12\x46\n\x07verdict\x18\x02 \x01(\x0b\x32,.com.digitalasset.canton.protocol.v2.VerdictR\x07verdict\x12\x1b\n\troot_hash\x18\x03 \x01(\x0cR\x08rootHash\x12\x1b\n\tdomain_id\x18\x04 \x01(\tR\x08\x64omainId\"\x96\x02\n\x07Verdict\x12\x32\n\x07\x61pprove\x18\x01 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00R\x07\x61pprove\x12g\n\x12participant_reject\x18\x02 \x01(\x0b\x32\x36.com.digitalasset.canton.protocol.v2.ParticipantRejectH\x00R\x11participantReject\x12^\n\x0fmediator_reject\x18\x03 \x01(\x0b\x32\x33.com.digitalasset.canton.protocol.v1.MediatorRejectH\x00R\x0emediatorRejectB\x0e\n\x0csome_verdict\"c\n\x11ParticipantReject\x12N\n\x07reasons\x18\x01 \x03(\x0b\x32\x34.com.digitalasset.canton.protocol.v2.RejectionReasonR\x07reasons\"u\n\x0fRejectionReason\x12\x18\n\x07parties\x18\x01 \x03(\tR\x07parties\x12H\n\x06reject\x18\x02 \x01(\x0b\x32\x30.com.digitalasset.canton.protocol.v1.LocalRejectR\x06reject\"\x89\x02\n\x0eTransferResult\x12\x39\n\nrequest_id\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\trequestId\x12%\n\rsource_domain\x18\x02 \x01(\tH\x00R\x0csourceDomain\x12%\n\rtarget_domain\x18\x03 \x01(\tH\x00R\x0ctargetDomain\x12\x1c\n\tinformees\x18\x04 \x03(\tR\tinformees\x12\x46\n\x07verdict\x18\x05 \x01(\x0b\x32,.com.digitalasset.canton.protocol.v2.VerdictR\x07verdictB\x08\n\x06\x64omain\"<\n\x0eMediatorReject\x12*\n\x06reason\x18\x01 \x01(\x0b\x32\x12.google.rpc.StatusR\x06reason\"\x97\x02\n\x1eMalformedMediatorRequestResult\x12\x39\n\nrequest_id\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\trequestId\x12\x1b\n\tdomain_id\x18\x02 \x01(\tR\x08\x64omainId\x12J\n\tview_type\x18\x03 \x01(\x0e\x32-.com.digitalasset.canton.protocol.v0.ViewTypeR\x08viewType\x12Q\n\trejection\x18\x04 \x01(\x0b\x32\x33.com.digitalasset.canton.protocol.v2.MediatorRejectR\trejectionBTZRgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/protocol/v2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.protocol.v2.mediator_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZRgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/protocol/v2'
  _globals['_TRANSACTIONRESULTMESSAGE']._serialized_start=342
  _globals['_TRANSACTIONRESULTMESSAGE']._serialized_end=557
  _globals['_VERDICT']._serialized_start=560
  _globals['_VERDICT']._serialized_end=838
  _globals['_PARTICIPANTREJECT']._serialized_start=840
  _globals['_PARTICIPANTREJECT']._serialized_end=939
  _globals['_REJECTIONREASON']._serialized_start=941
  _globals['_REJECTIONREASON']._serialized_end=1058
  _globals['_TRANSFERRESULT']._serialized_start=1061
  _globals['_TRANSFERRESULT']._serialized_end=1326
  _globals['_MEDIATORREJECT']._serialized_start=1328
  _globals['_MEDIATORREJECT']._serialized_end=1388
  _globals['_MALFORMEDMEDIATORREQUESTRESULT']._serialized_start=1391
  _globals['_MALFORMEDMEDIATORREQUESTRESULT']._serialized_end=1670
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/daml/ledger/api/v2/transaction.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/daml/ledger/api/v2/transaction.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import event_pb2 as com_dot_daml_dot_ledger_dot_api_dot_v2_dot_event__pb2
from . import trace_context_pb2 as com_dot_daml_dot_ledger_dot_api_dot_v2_dot_trace__context__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(com/daml/ledger/api/v2/transaction.proto\x12\x16\x63om.daml.ledger.api.v2\x1a\"com/daml/ledger/api/v2/event.proto\x1a*com/daml/ledger/api/v2/trace_context.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x9d\x01\n\tTreeEvent\x12@\n\x07\x63reated\x18\x01 \x01(\x0b\x32$.com.daml.ledger.api.v2.CreatedEventH\x00R\x07\x63reated\x12\x46\n\texercised\x18\x02 \x01(\x0b\x32&.com.daml.ledger.api.v2.ExercisedEventH\x00R\texercisedB\x06\n\x04kind\"\xcd\x04\n\x0fTransactionTree\x12\x1b\n\tupdate_id\x18\x01 \x01(\tR\x08updateId\x12\x1d\n\ncommand_id\x18\x02 \x01(\tR\tcommandId\x12\x1f\n\x0bworkflow_id\x18\x03 \x01(\tR\nworkflowId\x12=\n\x0c\x65\x66\x66\x65\x63tive_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0b\x65\x66\x66\x65\x63tiveAt\x12\x16\n\x06offset\x18\x05 \x01(\x03R\x06offset\x12Y\n\x0c\x65vents_by_id\x18\x06 \x03(\x0b\x32\x37.com.daml.ledger.api.v2.TransactionTree.EventsByIdEntryR\neventsById\x12$\n\x0eroot_event_ids\x18\x07 \x03(\tR\x0crootEventIds\x12\x1b\n\tdomain_id\x18\x08 \x01(\tR\x08\x64omainId\x12I\n\rtrace_context\x18\t \x01(\x0b\x32$.com.daml.ledger.api.v2.TraceContextR\x0ctraceContext\x12;\n\x0brecord_time\x18\n \x01(\x0b\x32\x1a.google.protobuf.TimestampR\nrecordTime\x1a`\n\x0f\x45ventsByIdEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x37\n\x05value\x18\x02 \x01(\x0b\x32!.com.daml.ledger.api.v2.TreeEventR\x05value:\x02\x38\x01\"\x9d\x03\n\x0bTransaction\x12\x1b\n\tupdate_id\x18\x01 \x01(\tR\x08updateId\x12\x1d\n\ncommand_id\x18\x02 \x01(\tR\tcommandId\x12\x1f\n\x0bworkflow_id\x18\x03 \x01(\tR\nworkflowId\x12=\n\x0c\x65\x66\x66\x65\x63tive_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0b\x65\x66\x66\x65\x63tiveAt\x12\x35\n\x06\x65vents\x18\x05 \x03(\x0b\x32\x1d.com.daml.ledger.api.v2.EventR\x06\x65vents\x12\x16\n\x06offset\x18\x06 \x01(\x03R\x06offset\x12\x1b\n\tdomain_id\x18\x07 \x01(\tR\x08\x64omainId\x12I\n\rtrace_context\x18\x08 \x01(\x0b\x32$.com.daml.ledger.api.v2.TraceContextR\x0ctraceContext\x12;\n\x0brecord_time\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampR\nrecordTimeB\x8f\x01\n\x16\x63om.daml.ledger.api.v2B\x15TransactionOuterClassZEgithub.com/digital-asset/dazl-client/v8/go/api/com/daml/ledger/api/v2\xaa\x02\x16\x43om.Daml.Ledger.Api.V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.daml.ledger.api.v2.transaction_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\026com.daml.ledger.api.v2B\025TransactionOuterClassZEgithub.com/digital-asset/dazl-client/v8/go/api/com/daml/ledger/api/v2\252\002\026Com.Daml.Ledger.Api.V2'
  _globals['_TRANSACTIONTREE_EVENTSBYIDENTRY']._loaded_options = None
  _globals['_TRANSACTIONTREE_EVENTSBYIDENTRY']._serialized_options = b'8\001'
  _globals['_TREEEVENT']._serialized_start=182
  _globals['_TREEEVENT']._serialized_end=339
  _globals['_TRANSACTIONTREE']._serialized_start=342
  _globals['_TRANSACTIONTREE']._serialized_end=931
  _globals['_TRANSACTIONTREE_EVENTSBYIDENTRY']._serialized_start=835
  _globals['_TRANSACTIONTREE_EVENTSBYIDENTRY']._serialized_end=931
  _globals['_TRANSACTION']._serialized_start=934
  _globals['_TRANSACTION']._serialized_end=1347
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file

import builtins as _builtins, typing as _typing

import grpc as _grpc
from grpc import aio as _grpc_aio

from .pruning_service_pb2 import GetSafePruningOffsetRequest, GetSafePruningOffsetResponse, PruneRequest, PruneResponse
from ....pruning.admin.v0.pruning_pb2 import ClearSchedule, GetParticipantSchedule, GetSchedule, SetCron, SetMaxDuration, SetParticipantSchedule, SetRetention, SetSchedule

__all__ = [
    "PruningServiceStub",
]


# noinspection PyPep8Naming,DuplicatedCode
class PruningServiceStub:
    @classmethod  # type: ignore
    @_typing.overload
    def __new__(cls, channel: _grpc.Channel) -> _PruningServiceBlockingStub: ...  # type: ignore
    @classmethod  # type: ignore
    @_typing.overload
    def __new__(cls, channel: _grpc_aio.Channel) -> _PruningServiceAsyncStub: ...  # type: ignore
    def Prune(self, __1: PruneRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[PruneResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, PruneResponse]]: ...
    def GetSafePruningOffset(self, __1: GetSafePruningOffsetRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[GetSafePruningOffsetResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, GetSafePruningOffsetResponse]]: ...
    def SetSchedule(self, __1: SetSchedule.Request, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[SetSchedule.Response, _grpc_aio.UnaryUnaryCall[_typing.Any, SetSchedule.Response]]: ...
    def SetParticipantSchedule(self, __1: SetParticipantSchedule.Request, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[SetParticipantSchedule.Response, _grpc_aio.UnaryUnaryCall[_typing.Any, SetParticipantSchedule.Response]]: ...
    def SetCron(self, __1: SetCron.Request, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[SetCron.Response, _grpc_aio.UnaryUnaryCall[_typing.Any, SetCron.Response]]: ...
    def SetMaxDuration(self, __1: SetMaxDuration.Request, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[SetMaxDuration.Response, _grpc_aio.UnaryUnaryCall[_typing.Any, SetMaxDuration.Response]]: ...
    def SetRetention(self, __1: SetRetention.Request, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[SetRetention.Response, _grpc_aio.UnaryUnaryCall[_typing.Any, SetRetention.Response]]: ...
    def ClearSchedule(self, __1: ClearSchedule.Request, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[ClearSchedule.Response, _grpc_aio.UnaryUnaryCall[_typing.Any, ClearSchedule.Response]]: ...
    def GetSchedule(self, __1: GetSchedule.Request, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[GetSchedule.Response, _grpc_aio.UnaryUnaryCall[_typing.Any, GetSchedule.Response]]: ...
    def GetParticipantSchedule(self, __1: GetParticipantSchedule.Request, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[GetParticipantSchedule.Response, _grpc_aio.UnaryUnaryCall[_typing.Any, GetParticipantSchedule.Response]]: ...

# noinspection PyPep8Naming,DuplicatedCode
class _PruningServiceBlockingStub(PruningServiceStub):
    def Prune(self, __1: PruneRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> PruneResponse: ...
    def GetSafePruningOffset(self, __1: GetSafePruningOffsetRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> GetSafePruningOffsetResponse: ...
    def SetSchedule(self, __1: SetSchedule.Request, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> SetSchedule.Response: ...
    def SetParticipantSchedule(self, __1: SetParticipantSchedule.Request, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> SetParticipantSchedule.Response: ...
    def SetCron(self, __1: SetCron.Request, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> SetCron.Response: ...
    def SetMaxDuration(self, __1: SetMaxDuration.Request, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> SetMaxDuration.Response: ...
    def SetRetention(self, __1: SetRetention.Request, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> SetRetention.Response: ...
    def ClearSchedule(self, __1: ClearSchedule.Request, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ClearSchedule.Response: ...
    def GetSchedule(self, __1: GetSchedule.Request, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> GetSchedule.Response: ...
    def GetParticipantSchedule(self, __1: GetParticipantSchedule.Request, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> GetParticipantSchedule.Response: ...

# noinspection PyPep8Naming,DuplicatedCode
class _PruningServiceAsyncStub(PruningServiceStub):
    def Prune(self, __1: PruneRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, PruneResponse]: ...  # type: ignore
    def GetSafePruningOffset(self, __1: GetSafePruningOffsetRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, GetSafePruningOffsetResponse]: ...  # type: ignore
    def SetSchedule(self, __1: SetSchedule.Request, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, SetSchedule.Response]: ...  # type: ignore
    def SetParticipantSchedule(self, __1: SetParticipantSchedule.Request, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, SetParticipantSchedule.Response]: ...  # type: ignore
    def SetCron(self, __1: SetCron.Request, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, SetCron.Response]: ...  # type: ignore
    def SetMaxDuration(self, __1: SetMaxDuration.Request, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, SetMaxDuration.Response]: ...  # type: ignore
    def SetRetention(self, __1: SetRetention.Request, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, SetRetention.Response]: ...  # type: ignore
    def ClearSchedule(self, __1: ClearSchedule.Request, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, ClearSchedule.Response]: ...  # type: ignore
    def GetSchedule(self, __1: GetSchedule.Request, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, GetSchedule.Response]: ...  # type: ignore
    def GetParticipantSchedule(self, __1: GetParticipantSchedule.Request, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, GetParticipantSchedule.Response]: ...  # type: ignore



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/topology/admin/v30/topology_manager_read_service.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/topology/admin/v30/topology_manager_read_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ....protocol.v30 import domain_parameters_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v30_dot_domain__parameters__pb2
from ....protocol.v30 import topology_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v30_dot_topology__pb2
from . import topology_ext_pb2 as com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__ext__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nNcom/digitalasset/canton/topology/admin/v30/topology_manager_read_service.proto\x12*com.digitalasset.canton.topology.admin.v30\x1a<com/digitalasset/canton/protocol/v30/domain_parameters.proto\x1a\x33\x63om/digitalasset/canton/protocol/v30/topology.proto\x1a=com/digitalasset/canton/topology/admin/v30/topology_ext.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\"\x9e\x05\n\tBaseQuery\x12T\n\x0c\x66ilter_store\x18\x01 \x01(\x0b\x32\x31.com.digitalasset.canton.topology.admin.v30.StoreR\x0b\x66ilterStore\x12\x1c\n\tproposals\x18\x02 \x01(\x08R\tproposals\x12Z\n\toperation\x18\x03 \x01(\x0e\x32<.com.digitalasset.canton.protocol.v30.Enums.TopologyChangeOpR\toperation\x12\x38\n\x08snapshot\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00R\x08snapshot\x12\x37\n\nhead_state\x18\x06 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00R\theadState\x12W\n\x05range\x18\x07 \x01(\x0b\x32?.com.digitalasset.canton.topology.admin.v30.BaseQuery.TimeRangeH\x00R\x05range\x12*\n\x11\x66ilter_signed_key\x18\x08 \x01(\tR\x0f\x66ilterSignedKey\x12\x46\n\x10protocol_version\x18\t \x01(\x0b\x32\x1b.google.protobuf.Int32ValueR\x0fprotocolVersion\x1am\n\tTimeRange\x12.\n\x04\x66rom\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x04\x66rom\x12\x30\n\x05until\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x05untilB\x0c\n\ntime_queryJ\x04\x08\x04\x10\x05\"\xec\x01\n\x05Store\x12^\n\nauthorized\x18\x01 \x01(\x0b\x32<.com.digitalasset.canton.topology.admin.v30.Store.AuthorizedH\x00R\nauthorized\x12R\n\x06\x64omain\x18\x02 \x01(\x0b\x32\x38.com.digitalasset.canton.topology.admin.v30.Store.DomainH\x00R\x06\x64omain\x1a\x0c\n\nAuthorized\x1a\x18\n\x06\x44omain\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02idB\x07\n\x05store\"\xdc\x03\n\nBaseResult\x12G\n\x05store\x18\x01 \x01(\x0b\x32\x31.com.digitalasset.canton.topology.admin.v30.StoreR\x05store\x12\x38\n\tsequenced\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tsequenced\x12\x39\n\nvalid_from\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tvalidFrom\x12;\n\x0bvalid_until\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\nvalidUntil\x12Z\n\toperation\x18\x05 \x01(\x0e\x32<.com.digitalasset.canton.protocol.v30.Enums.TopologyChangeOpR\toperation\x12)\n\x10transaction_hash\x18\x06 \x01(\x0cR\x0ftransactionHash\x12\x16\n\x06serial\x18\x07 \x01(\x05R\x06serial\x12\x34\n\x16signed_by_fingerprints\x18\x08 \x03(\tR\x14signedByFingerprints\"\xe4\x01\n\x1eListNamespaceDelegationRequest\x12T\n\nbase_query\x18\x01 \x01(\x0b\x32\x35.com.digitalasset.canton.topology.admin.v30.BaseQueryR\tbaseQuery\x12)\n\x10\x66ilter_namespace\x18\x02 \x01(\tR\x0f\x66ilterNamespace\x12\x41\n\x1d\x66ilter_target_key_fingerprint\x18\x03 \x01(\tR\x1a\x66ilterTargetKeyFingerprint\"\xbb\x02\n\x1fListNamespaceDelegationResponse\x12l\n\x07results\x18\x01 \x03(\x0b\x32R.com.digitalasset.canton.topology.admin.v30.ListNamespaceDelegationResponse.ResultR\x07results\x1a\xa9\x01\n\x06Result\x12P\n\x07\x63ontext\x18\x01 \x01(\x0b\x32\x36.com.digitalasset.canton.topology.admin.v30.BaseResultR\x07\x63ontext\x12M\n\x04item\x18\x02 \x01(\x0b\x32\x39.com.digitalasset.canton.protocol.v30.NamespaceDelegationR\x04item\"\xae\x01\n+ListDecentralizedNamespaceDefinitionRequest\x12T\n\nbase_query\x18\x01 \x01(\x0b\x32\x35.com.digitalasset.canton.topology.admin.v30.BaseQueryR\tbaseQuery\x12)\n\x10\x66ilter_namespace\x18\x02 \x01(\tR\x0f\x66ilterNamespace\"\xe2\x02\n,ListDecentralizedNamespaceDefinitionResponse\x12y\n\x07results\x18\x01 \x03(\x0b\x32_.com.digitalasset.canton.topology.admin.v30.ListDecentralizedNamespaceDefinitionResponse.ResultR\x07results\x1a\xb6\x01\n\x06Result\x12P\n\x07\x63ontext\x18\x01 \x01(\x0b\x32\x36.com.digitalasset.canton.topology.admin.v30.BaseResultR\x07\x63ontext\x12Z\n\x04item\x18\x02 \x01(\x0b\x32\x46.com.digitalasset.canton.protocol.v30.DecentralizedNamespaceDefinitionR\x04item\"\xd9\x01\n\x1fListIdentifierDelegationRequest\x12T\n\nbase_query\x18\x01 \x01(\x0b\x32\x35.com.digitalasset.canton.topology.admin.v30.BaseQueryR\tbaseQuery\x12\x1d\n\nfilter_uid\x18\x02 \x01(\tR\tfilterUid\x12\x41\n\x1d\x66ilter_target_key_fingerprint\x18\x03 \x01(\tR\x1a\x66ilterTargetKeyFingerprint\"\xbe\x02\n ListIdentifierDelegationResponse\x12m\n\x07results\x18\x01 \x03(\x0b\x32S.com.digitalasset.canton.topology.admin.v30.ListIdentifierDelegationResponse.ResultR\x07results\x1a\xaa\x01\n\x06Result\x12P\n\x07\x63ontext\x18\x01 \x01(\x0b\x32\x36.com.digitalasset.canton.topology.admin.v30.BaseResultR\x07\x63ontext\x12N\n\x04item\x18\x02 \x01(\x0b\x32:.com.digitalasset.canton.protocol.v30.IdentifierDelegationR\x04item\"\xd8\x01\n\x1cListOwnerToKeyMappingRequest\x12T\n\nbase_query\x18\x01 \x01(\x0b\x32\x35.com.digitalasset.canton.topology.admin.v30.BaseQueryR\tbaseQuery\x12\x31\n\x15\x66ilter_key_owner_type\x18\x02 \x01(\tR\x12\x66ilterKeyOwnerType\x12/\n\x14\x66ilter_key_owner_uid\x18\x03 \x01(\tR\x11\x66ilterKeyOwnerUid\"\xb5\x02\n\x1dListOwnerToKeyMappingResponse\x12j\n\x07results\x18\x01 \x03(\x0b\x32P.com.digitalasset.canton.topology.admin.v30.ListOwnerToKeyMappingResponse.ResultR\x07results\x1a\xa7\x01\n\x06Result\x12P\n\x07\x63ontext\x18\x01 \x01(\x0b\x32\x36.com.digitalasset.canton.topology.admin.v30.BaseResultR\x07\x63ontext\x12K\n\x04item\x18\x02 \x01(\x0b\x32\x37.com.digitalasset.canton.protocol.v30.OwnerToKeyMappingR\x04item\"\x97\x01\n\x1cListPartyToKeyMappingRequest\x12T\n\nbase_query\x18\x01 \x01(\x0b\x32\x35.com.digitalasset.canton.topology.admin.v30.BaseQueryR\tbaseQuery\x12!\n\x0c\x66ilter_party\x18\x02 \x01(\tR\x0b\x66ilterParty\"\xb5\x02\n\x1dListPartyToKeyMappingResponse\x12j\n\x07results\x18\x01 \x03(\x0b\x32P.com.digitalasset.canton.topology.admin.v30.ListPartyToKeyMappingResponse.ResultR\x07results\x1a\xa7\x01\n\x06Result\x12P\n\x07\x63ontext\x18\x01 \x01(\x0b\x32\x36.com.digitalasset.canton.topology.admin.v30.BaseResultR\x07\x63ontext\x12K\n\x04item\x18\x02 \x01(\x0b\x32\x37.com.digitalasset.canton.protocol.v30.PartyToKeyMappingR\x04item\"\x98\x01\n!ListDomainTrustCertificateRequest\x12T\n\nbase_query\x18\x01 \x01(\x0b\x32\x35.com.digitalasset.canton.topology.admin.v30.BaseQueryR\tbaseQuery\x12\x1d\n\nfilter_uid\x18\x02 \x01(\tR\tfilterUid\"\xc4\x02\n\"ListDomainTrustCertificateResponse\x12o\n\x07results\x18\x01 \x03(\x0b\x32U.com.digitalasset.canton.topology.admin.v30.ListDomainTrustCertificateResponse.ResultR\x07results\x1a\xac\x01\n\x06Result\x12P\n\x07\x63ontext\x18\x01 \x01(\x0b\x32\x36.com.digitalasset.canton.topology.admin.v30.BaseResultR\x07\x63ontext\x12P\n\x04item\x18\x02 \x01(\x0b\x32<.com.digitalasset.canton.protocol.v30.DomainTrustCertificateR\x04item\"\x9d\x01\n&ListParticipantDomainPermissionRequest\x12T\n\nbase_query\x18\x01 \x01(\x0b\x32\x35.com.digitalasset.canton.topology.admin.v30.BaseQueryR\tbaseQuery\x12\x1d\n\nfilter_uid\x18\x02 \x01(\tR\tfilterUid\"\xd3\x02\n\'ListParticipantDomainPermissionResponse\x12t\n\x07results\x18\x01 \x03(\x0b\x32Z.com.digitalasset.canton.topology.admin.v30.ListParticipantDomainPermissionResponse.ResultR\x07results\x1a\xb1\x01\n\x06Result\x12P\n\x07\x63ontext\x18\x01 \x01(\x0b\x32\x36.com.digitalasset.canton.topology.admin.v30.BaseResultR\x07\x63ontext\x12U\n\x04item\x18\x02 \x01(\x0b\x32\x41.com.digitalasset.canton.protocol.v30.ParticipantDomainPermissionR\x04item\"\x94\x01\n\x1dListPartyHostingLimitsRequest\x12T\n\nbase_query\x18\x01 \x01(\x0b\x32\x35.com.digitalasset.canton.topology.admin.v30.BaseQueryR\tbaseQuery\x12\x1d\n\nfilter_uid\x18\x02 \x01(\tR\tfilterUid\"\xb8\x02\n\x1eListPartyHostingLimitsResponse\x12k\n\x07results\x18\x01 \x03(\x0b\x32Q.com.digitalasset.canton.topology.admin.v30.ListPartyHostingLimitsResponse.ResultR\x07results\x1a\xa8\x01\n\x06Result\x12P\n\x07\x63ontext\x18\x01 \x01(\x0b\x32\x36.com.digitalasset.canton.topology.admin.v30.BaseResultR\x07\x63ontext\x12L\n\x04item\x18\x02 \x01(\x0b\x32\x38.com.digitalasset.canton.protocol.v30.PartyHostingLimitsR\x04item\"\xa0\x01\n\x19ListVettedPackagesRequest\x12T\n\nbase_query\x18\x01 \x01(\x0b\x32\x35.com.digitalasset.canton.topology.admin.v30.BaseQueryR\tbaseQuery\x12-\n\x12\x66ilter_participant\x18\x02 \x01(\tR\x11\x66ilterParticipant\"\xac\x02\n\x1aListVettedPackagesResponse\x12g\n\x07results\x18\x01 \x03(\x0b\x32M.com.digitalasset.canton.topology.admin.v30.ListVettedPackagesResponse.ResultR\x07results\x1a\xa4\x01\n\x06Result\x12P\n\x07\x63ontext\x18\x01 \x01(\x0b\x32\x36.com.digitalasset.canton.topology.admin.v30.BaseResultR\x07\x63ontext\x12H\n\x04item\x18\x02 \x01(\x0b\x32\x34.com.digitalasset.canton.protocol.v30.VettedPackagesR\x04item\"\xc7\x01\n\x1dListPartyToParticipantRequest\x12T\n\nbase_query\x18\x01 \x01(\x0b\x32\x35.com.digitalasset.canton.topology.admin.v30.BaseQueryR\tbaseQuery\x12!\n\x0c\x66ilter_party\x18\x02 \x01(\tR\x0b\x66ilterParty\x12-\n\x12\x66ilter_participant\x18\x03 \x01(\tR\x11\x66ilterParticipant\"\xb8\x02\n\x1eListPartyToParticipantResponse\x12k\n\x07results\x18\x02 \x03(\x0b\x32Q.com.digitalasset.canton.topology.admin.v30.ListPartyToParticipantResponse.ResultR\x07results\x1a\xa8\x01\n\x06Result\x12P\n\x07\x63ontext\x18\x01 \x01(\x0b\x32\x36.com.digitalasset.canton.topology.admin.v30.BaseResultR\x07\x63ontext\x12L\n\x04item\x18\x02 \x01(\x0b\x32\x38.com.digitalasset.canton.protocol.v30.PartyToParticipantR\x04item\"\x91\x01\n\x16ListAuthorityOfRequest\x12T\n\nbase_query\x18\x01 \x01(\x0b\x32\x35.com.digitalasset.canton.topology.admin.v30.BaseQueryR\tbaseQuery\x12!\n\x0c\x66ilter_party\x18\x02 \x01(\tR\x0b\x66ilterParty\"\xa3\x02\n\x17ListAuthorityOfResponse\x12\x64\n\x07results\x18\x02 \x03(\x0b\x32J.com.digitalasset.canton.topology.admin.v30.ListAuthorityOfResponse.ResultR\x07results\x1a\xa1\x01\n\x06Result\x12P\n\x07\x63ontext\x18\x01 \x01(\x0b\x32\x36.com.digitalasset.canton.topology.admin.v30.BaseResultR\x07\x63ontext\x12\x45\n\x04item\x18\x02 \x01(\x0b\x32\x31.com.digitalasset.canton.protocol.v30.AuthorityOfR\x04item\"\x9d\x01\n ListDomainParametersStateRequest\x12T\n\nbase_query\x18\x01 \x01(\x0b\x32\x35.com.digitalasset.canton.topology.admin.v30.BaseQueryR\tbaseQuery\x12#\n\rfilter_domain\x18\x02 \x01(\tR\x0c\x66ilterDomain\"\xc3\x02\n!ListDomainParametersStateResponse\x12n\n\x07results\x18\x01 \x03(\x0b\x32T.com.digitalasset.canton.topology.admin.v30.ListDomainParametersStateResponse.ResultR\x07results\x1a\xad\x01\n\x06Result\x12P\n\x07\x63ontext\x18\x01 \x01(\x0b\x32\x36.com.digitalasset.canton.topology.admin.v30.BaseResultR\x07\x63ontext\x12Q\n\x04item\x18\x02 \x01(\x0b\x32=.com.digitalasset.canton.protocol.v30.DynamicDomainParametersR\x04item\"\x9b\x01\n\x1eListMediatorDomainStateRequest\x12T\n\nbase_query\x18\x01 \x01(\x0b\x32\x35.com.digitalasset.canton.topology.admin.v30.BaseQueryR\tbaseQuery\x12#\n\rfilter_domain\x18\x02 \x01(\tR\x0c\x66ilterDomain\"\xbb\x02\n\x1fListMediatorDomainStateResponse\x12l\n\x07results\x18\x01 \x03(\x0b\x32R.com.digitalasset.canton.topology.admin.v30.ListMediatorDomainStateResponse.ResultR\x07results\x1a\xa9\x01\n\x06Result\x12P\n\x07\x63ontext\x18\x01 \x01(\x0b\x32\x36.com.digitalasset.canton.topology.admin.v30.BaseResultR\x07\x63ontext\x12M\n\x04item\x18\x02 \x01(\x0b\x32\x39.com.digitalasset.canton.protocol.v30.MediatorDomainStateR\x04item\"\x9c\x01\n\x1fListSequencerDomainStateRequest\x12T\n\nbase_query\x18\x01 \x01(\x0b\x32\x35.com.digitalasset.canton.topology.admin.v30.BaseQueryR\tbaseQuery\x12#\n\rfilter_domain\x18\x02 \x01(\tR\x0c\x66ilterDomain\"\xbe\x02\n ListSequencerDomainStateResponse\x12m\n\x07results\x18\x01 \x03(\x0b\x32S.com.digitalasset.canton.topology.admin.v30.ListSequencerDomainStateResponse.ResultR\x07results\x1a\xaa\x01\n\x06Result\x12P\n\x07\x63ontext\x18\x01 \x01(\x0b\x32\x36.com.digitalasset.canton.topology.admin.v30.BaseResultR\x07\x63ontext\x12N\n\x04item\x18\x02 \x01(\x0b\x32:.com.digitalasset.canton.protocol.v30.SequencerDomainStateR\x04item\"\xa0\x01\n#ListPurgeTopologyTransactionRequest\x12T\n\nbase_query\x18\x01 \x01(\x0b\x32\x35.com.digitalasset.canton.topology.admin.v30.BaseQueryR\tbaseQuery\x12#\n\rfilter_domain\x18\x02 \x01(\tR\x0c\x66ilterDomain\"\xca\x02\n$ListPurgeTopologyTransactionResponse\x12q\n\x07results\x18\x01 \x03(\x0b\x32W.com.digitalasset.canton.topology.admin.v30.ListPurgeTopologyTransactionResponse.ResultR\x07results\x1a\xae\x01\n\x06Result\x12P\n\x07\x63ontext\x18\x01 \x01(\x0b\x32\x36.com.digitalasset.canton.topology.admin.v30.BaseResultR\x07\x63ontext\x12R\n\x04item\x18\x02 \x01(\x0b\x32>.com.digitalasset.canton.protocol.v30.PurgeTopologyTransactionR\x04item\"\x1c\n\x1aListAvailableStoresRequest\":\n\x1bListAvailableStoresResponse\x12\x1b\n\tstore_ids\x18\x01 \x03(\tR\x08storeIds\"\xbc\x01\n\x0eListAllRequest\x12T\n\nbase_query\x18\x01 \x01(\x0b\x32\x35.com.digitalasset.canton.topology.admin.v30.BaseQueryR\tbaseQuery\x12)\n\x10\x65xclude_mappings\x18\x02 \x03(\tR\x0f\x65xcludeMappings\x12)\n\x10\x66ilter_namespace\x18\x03 \x01(\tR\x0f\x66ilterNamespace\"\xcb\x01\n\x1d\x45xportTopologySnapshotRequest\x12T\n\nbase_query\x18\x01 \x01(\x0b\x32\x35.com.digitalasset.canton.topology.admin.v30.BaseQueryR\tbaseQuery\x12)\n\x10\x65xclude_mappings\x18\x02 \x03(\tR\x0f\x65xcludeMappings\x12)\n\x10\x66ilter_namespace\x18\x03 \x01(\tR\x0f\x66ilterNamespace\"k\n\x0fListAllResponse\x12X\n\x06result\x18\x01 \x01(\x0b\x32@.com.digitalasset.canton.topology.admin.v30.TopologyTransactionsR\x06result\"8\n\x1e\x45xportTopologySnapshotResponse\x12\x16\n\x06result\x18\x01 \x01(\x0cR\x06result\"\xb2\x01\n\x13GenesisStateRequest\x12\x61\n\x13\x66ilter_domain_store\x18\x01 \x01(\x0b\x32\x31.com.digitalasset.canton.topology.admin.v30.StoreR\x11\x66ilterDomainStore\x12\x38\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimestamp\",\n\x14GenesisStateResponse\x12\x14\n\x05\x63hunk\x18\x01 \x01(\x0cR\x05\x63hunk2\xd7\x1a\n\x1aTopologyManagerReadService\x12\xb2\x01\n\x17ListNamespaceDelegation\x12J.com.digitalasset.canton.topology.admin.v30.ListNamespaceDelegationRequest\x1aK.com.digitalasset.canton.topology.admin.v30.ListNamespaceDelegationResponse\x12\xd9\x01\n$ListDecentralizedNamespaceDefinition\x12W.com.digitalasset.canton.topology.admin.v30.ListDecentralizedNamespaceDefinitionRequest\x1aX.com.digitalasset.canton.topology.admin.v30.ListDecentralizedNamespaceDefinitionResponse\x12\xb5\x01\n\x18ListIdentifierDelegation\x12K.com.digitalasset.canton.topology.admin.v30.ListIdentifierDelegationRequest\x1aL.com.digitalasset.canton.topology.admin.v30.ListIdentifierDelegationResponse\x12\xac\x01\n\x15ListOwnerToKeyMapping\x12H.com.digitalasset.canton.topology.admin.v30.ListOwnerToKeyMappingRequest\x1aI.com.digitalasset.canton.topology.admin.v30.ListOwnerToKeyMappingResponse\x12\xac\x01\n\x15ListPartyToKeyMapping\x12H.com.digitalasset.canton.topology.admin.v30.ListPartyToKeyMappingRequest\x1aI.com.digitalasset.canton.topology.admin.v30.ListPartyToKeyMappingResponse\x12\xbb\x01\n\x1aListDomainTrustCertificate\x12M.com.digitalasset.canton.topology.admin.v30.ListDomainTrustCertificateRequest\x1aN.com.digitalasset.canton.topology.admin.v30.ListDomainTrustCertificateResponse\x12\xca\x01\n\x1fListParticipantDomainPermission\x12R.com.digitalasset.canton.topology.admin.v30.ListParticipantDomainPermissionRequest\x1aS.com.digitalasset.canton.topology.admin.v30.ListParticipantDomainPermissionResponse\x12\xaf\x01\n\x16ListPartyHostingLimits\x12I.com.digitalasset.canton.topology.admin.v30.ListPartyHostingLimitsRequest\x1aJ.com.digitalasset.canton.topology.admin.v30.ListPartyHostingLimitsResponse\x12\xa3\x01\n\x12ListVettedPackages\x12\x45.com.digitalasset.canton.topology.admin.v30.ListVettedPackagesRequest\x1a\x46.com.digitalasset.canton.topology.admin.v30.ListVettedPackagesResponse\x12\xaf\x01\n\x16ListPartyToParticipant\x12I.com.digitalasset.canton.topology.admin.v30.ListPartyToParticipantRequest\x1aJ.com.digitalasset.canton.topology.admin.v30.ListPartyToParticipantResponse\x12\x9a\x01\n\x0fListAuthorityOf\x12\x42.com.digitalasset.canton.topology.admin.v30.ListAuthorityOfRequest\x1a\x43.com.digitalasset.canton.topology.admin.v30.ListAuthorityOfResponse\x12\xb8\x01\n\x19ListDomainParametersState\x12L.com.digitalasset.canton.topology.admin.v30.ListDomainParametersStateRequest\x1aM.com.digitalasset.canton.topology.admin.v30.ListDomainParametersStateResponse\x12\xb2\x01\n\x17ListMediatorDomainState\x12J.com.digitalasset.canton.topology.admin.v30.ListMediatorDomainStateRequest\x1aK.com.digitalasset.canton.topology.admin.v30.ListMediatorDomainStateResponse\x12\xb5\x01\n\x18ListSequencerDomainState\x12K.com.digitalasset.canton.topology.admin.v30.ListSequencerDomainStateRequest\x1aL.com.digitalasset.canton.topology.admin.v30.ListSequencerDomainStateResponse\x12\xc1\x01\n\x1cListPurgeTopologyTransaction\x12O.com.digitalasset.canton.topology.admin.v30.ListPurgeTopologyTransactionRequest\x1aP.com.digitalasset.canton.topology.admin.v30.ListPurgeTopologyTransactionResponse\x12\xa6\x01\n\x13ListAvailableStores\x12\x46.com.digitalasset.canton.topology.admin.v30.ListAvailableStoresRequest\x1aG.com.digitalasset.canton.topology.admin.v30.ListAvailableStoresResponse\x12\x82\x01\n\x07ListAll\x12:.com.digitalasset.canton.topology.admin.v30.ListAllRequest\x1a;.com.digitalasset.canton.topology.admin.v30.ListAllResponse\x12\xaf\x01\n\x16\x45xportTopologySnapshot\x12I.com.digitalasset.canton.topology.admin.v30.ExportTopologySnapshotRequest\x1aJ.com.digitalasset.canton.topology.admin.v30.ExportTopologySnapshotResponse\x12\x93\x01\n\x0cGenesisState\x12?.com.digitalasset.canton.topology.admin.v30.GenesisStateRequest\x1a@.com.digitalasset.canton.topology.admin.v30.GenesisStateResponse0\x01\x42[ZYgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/topology/admin/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.topology.admin.v30.topology_manager_read_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZYgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/topology/admin/v30'
  _globals['_BASEQUERY']._serialized_start=399
  _globals['_BASEQUERY']._serialized_end=1069
  _globals['_BASEQUERY_TIMERANGE']._serialized_start=940
  _globals['_BASEQUERY_TIMERANGE']._serialized_end=1049
  _globals['_STORE']._serialized_start=1072
  _globals['_STORE']._serialized_end=1308
  _globals['_STORE_AUTHORIZED']._serialized_start=1261
  _globals['_STORE_AUTHORIZED']._serialized_end=1273
  _globals['_STORE_DOMAIN']._serialized_start=1275
  _globals['_STORE_DOMAIN']._serialized_end=1299
  _globals['_BASERESULT']._serialized_start=1311
  _globals['_BASERESULT']._serialized_end=1787
  _globals['_LISTNAMESPACEDELEGATIONREQUEST']._serialized_start=1790
  _globals['_LISTNAMESPACEDELEGATIONREQUEST']._serialized_end=2018
  _globals['_LISTNAMESPACEDELEGATIONRESPONSE']._serialized_start=2021
  _globals['_LISTNAMESPACEDELEGATIONRESPONSE']._serialized_end=2336
  _globals['_LISTNAMESPACEDELEGATIONRESPONSE_RESULT']._serialized_start=2167
  _globals['_LISTNAMESPACEDELEGATIONRESPONSE_RESULT']._serialized_end=2336
  _globals['_LISTDECENTRALIZEDNAMESPACEDEFINITIONREQUEST']._serialized_start=2339
  _globals['_LISTDECENTRALIZEDNAMESPACEDEFINITIONREQUEST']._serialized_end=2513
  _globals['_LISTDECENTRALIZEDNAMESPACEDEFINITIONRESPONSE']._serialized_start=2516
  _globals['_LISTDECENTRALIZEDNAMESPACEDEFINITIONRESPONSE']._serialized_end=2870
  _globals['_LISTDECENTRALIZEDNAMESPACEDEFINITIONRESPONSE_RESULT']._serialized_start=2688
  _globals['_LISTDECENTRALIZEDNAMESPACEDEFINITIONRESPONSE_RESULT']._serialized_end=2870
  _globals['_LISTIDENTIFIERDELEGATIONREQUEST']._serialized_start=2873
  _globals['_LISTIDENTIFIERDELEGATIONREQUEST']._serialized_end=3090
  _globals['_LISTIDENTIFIERDELEGATIONRESPONSE']._serialized_start=3093
  _globals['_LISTIDENTIFIERDELEGATIONRESPONSE']._serialized_end=3411
  _globals['_LISTIDENTIFIERDELEGATIONRESPONSE_RESULT']._serialized_start=3241
  _globals['_LISTIDENTIFIERDELEGATIONRESPONSE_RESULT']._serialized_end=3411
  _globals['_LISTOWNERTOKEYMAPPINGREQUEST']._serialized_start=3414
  _globals['_LISTOWNERTOKEYMAPPINGREQUEST']._serialized_end=3630
  _globals['_LISTOWNERTOKEYMAPPINGRESPONSE']._serialized_start=3633
  _globals['_LISTOWNERTOKEYMAPPINGRESPONSE']._serialized_end=3942
  _globals['_LISTOWNERTOKEYMAPPINGRESPONSE_RESULT']._serialized_start=3775
  _globals['_LISTOWNERTOKEYMAPPINGRESPONSE_RESULT']._serialized_end=3942
  _globals['_LISTPARTYTOKEYMAPPINGREQUEST']._serialized_start=3945
  _globals['_LISTPARTYTOKEYMAPPINGREQUEST']._serialized_end=4096
  _globals['_LISTPARTYTOKEYMAPPINGRESPONSE']._serialized_start=4099
  _globals['_LISTPARTYTOKEYMAPPINGRESPONSE']._serialized_end=4408
  _globals['_LISTPARTYTOKEYMAPPINGRESPONSE_RESULT']._serialized_start=4241
  _globals['_LISTPARTYTOKEYMAPPINGRESPONSE_RESULT']._serialized_end=4408
  _globals['_LISTDOMAINTRUSTCERTIFICATEREQUEST']._serialized_start=4411
  _globals['_LISTDOMAINTRUSTCERTIFICATEREQUEST']._serialized_end=4563
  _globals['_LISTDOMAINTRUSTCERTIFICATERESPONSE']._serialized_start=4566
  _globals['_LISTDOMAINTRUSTCERTIFICATERESPONSE']._serialized_end=4890
  _globals['_LISTDOMAINTRUSTCERTIFICATERESPONSE_RESULT']._serialized_start=4718
  _globals['_LISTDOMAINTRUSTCERTIFICATERESPONSE_RESULT']._serialized_end=4890
  _globals['_LISTPARTICIPANTDOMAINPERMISSIONREQUEST']._serialized_start=4893
  _globals['_LISTPARTICIPANTDOMAINPERMISSIONREQUEST']._serialized_end=5050
  _globals['_LISTPARTICIPANTDOMAINPERMISSIONRESPONSE']._serialized_start=5053
  _globals['_LISTPARTICIPANTDOMAINPERMISSIONRESPONSE']._serialized_end=5392
  _globals['_LISTPARTICIPANTDOMAINPERMISSIONRESPONSE_RESULT']._serialized_start=5215
  _globals['_LISTPARTICIPANTDOMAINPERMISSIONRESPONSE_RESULT']._serialized_end=5392
  _globals['_LISTPARTYHOSTINGLIMITSREQUEST']._serialized_start=5395
  _globals['_LISTPARTYHOSTINGLIMITSREQUEST']._serialized_end=5543
  _globals['_LISTPARTYHOSTINGLIMITSRESPONSE']._serialized_start=5546
  _globals['_LISTPARTYHOSTINGLIMITSRESPONSE']._serialized_end=5858
  _globals['_LISTPARTYHOSTINGLIMITSRESPONSE_RESULT']._serialized_start=5690
  _globals['_LISTPARTYHOSTINGLIMITSRESPONSE_RESULT']._serialized_end=5858
  _globals['_LISTVETTEDPACKAGESREQUEST']._serialized_start=5861
  _globals['_LISTVETTEDPACKAGESREQUEST']._serialized_end=6021
  _globals['_LISTVETTEDPACKAGESRESPONSE']._serialized_start=6024
  _globals['_LISTVETTEDPACKAGESRESPONSE']._serialized_end=6324
  _globals['_LISTVETTEDPACKAGESRESPONSE_RESULT']._serialized_start=6160
  _globals['_LISTVETTEDPACKAGESRESPONSE_RESULT']._serialized_end=6324
  _globals['_LISTPARTYTOPARTICIPANTREQUEST']._serialized_start=6327
  _globals['_LISTPARTYTOPARTICIPANTREQUEST']._serialized_end=6526
  _globals['_LISTPARTYTOPARTICIPANTRESPONSE']._serialized_start=6529
  _globals['_LISTPARTYTOPARTICIPANTRESPONSE']._serialized_end=6841
  _globals['_LISTPARTYTOPARTICIPANTRESPONSE_RESULT']._serialized_start=6673
  _globals['_LISTPARTYTOPARTICIPANTRESPONSE_RESULT']._serialized_end=6841
  _globals['_LISTAUTHORITYOFREQUEST']._serialized_start=6844
  _globals['_LISTAUTHORITYOFREQUEST']._serialized_end=6989
  _globals['_LISTAUTHORITYOFRESPONSE']._serialized_start=6992
  _globals['_LISTAUTHORITYOFRESPONSE']._serialized_end=7283
  _globals['_LISTAUTHORITYOFRESPONSE_RESULT']._serialized_start=7122
  _globals['_LISTAUTHORITYOFRESPONSE_RESULT']._serialized_end=7283
  _globals['_LISTDOMAINPARAMETERSSTATEREQUEST']._serialized_start=7286
  _globals['_LISTDOMAINPARAMETERSSTATEREQUEST']._serialized_end=7443
  _globals['_LISTDOMAINPARAMETERSSTATERESPONSE']._serialized_start=7446
  _globals['_LISTDOMAINPARAMETERSSTATERESPONSE']._serialized_end=7769
  _globals['_LISTDOMAINPARAMETERSSTATERESPONSE_RESULT']._serialized_start=7596
  _globals['_LISTDOMAINPARAMETERSSTATERESPONSE_RESULT']._serialized_end=7769
  _globals['_LISTMEDIATORDOMAINSTATEREQUEST']._serialized_start=7772
  _globals['_LISTMEDIATORDOMAINSTATEREQUEST']._serialized_end=7927
  _globals['_LISTMEDIATORDOMAINSTATERESPONSE']._serialized_start=7930
  _globals['_LISTMEDIATORDOMAINSTATERESPONSE']._serialized_end=8245
  _globals['_LISTMEDIATORDOMAINSTATERESPONSE_RESULT']._serialized_start=8076
  _globals['_LISTMEDIATORDOMAINSTATERESPONSE_RESULT']._serialized_end=8245
  _globals['_LISTSEQUENCERDOMAINSTATEREQUEST']._serialized_start=8248
  _globals['_LISTSEQUENCERDOMAINSTATEREQUEST']._serialized_end=8404
  _globals['_LISTSEQUENCERDOMAINSTATERESPONSE']._serialized_start=8407
  _globals['_LISTSEQUENCERDOMAINSTATERESPONSE']._serialized_end=8725
  _globals['_LISTSEQUENCERDOMAINSTATERESPONSE_RESULT']._serialized_start=8555
  _globals['_LISTSEQUENCERDOMAINSTATERESPONSE_RESULT']._serialized_end=8725
  _globals['_LISTPURGETOPOLOGYTRANSACTIONREQUEST']._serialized_start=8728
  _globals['_LISTPURGETOPOLOGYTRANSACTIONREQUEST']._serialized_end=8888
  _globals['_LISTPURGETOPOLOGYTRANSACTIONRESPONSE']._serialized_start=8891
  _globals['_LISTPURGETOPOLOGYTRANSACTIONRESPONSE']._serialized_end=9221
  _globals['_LISTPURGETOPOLOGYTRANSACTIONRESPONSE_RESULT']._serialized_start=9047
  _globals['_LISTPURGETOPOLOGYTRANSACTIONRESPONSE_RESULT']._serialized_end=9221
  _globals['_LISTAVAILABLESTORESREQUEST']._serialized_start=9223
  _globals['_LISTAVAILABLESTORESREQUEST']._serialized_end=9251
  _globals['_LISTAVAILABLESTORESRESPONSE']._serialized_start=9253
  _globals['_LISTAVAILABLESTORESRESPONSE']._serialized_end=9311
  _globals['_LISTALLREQUEST']._serialized_start=9314
  _globals['_LISTALLREQUEST']._serialized_end=9502
  _globals['_EXPORTTOPOLOGYSNAPSHOTREQUEST']._serialized_start=9505
  _globals['_EXPORTTOPOLOGYSNAPSHOTREQUEST']._serialized_end=9708
  _globals['_LISTALLRESPONSE']._serialized_start=9710
  _globals['_LISTALLRESPONSE']._serialized_end=9817
  _globals['_EXPORTTOPOLOGYSNAPSHOTRESPONSE']._serialized_start=9819
  _globals['_EXPORTTOPOLOGYSNAPSHOTRESPONSE']._serialized_end=9875
  _globals['_GENESISSTATEREQUEST']._serialized_start=9878
  _globals['_GENESISSTATEREQUEST']._serialized_end=10056
  _globals['_GENESISSTATERESPONSE']._serialized_start=10058
  _globals['_GENESISSTATERESPONSE']._serialized_end=10102
  _globals['_TOPOLOGYMANAGERREADSERVICE']._serialized_start=10105
  _globals['_TOPOLOGYMANAGERREADSERVICE']._serialized_end=13520
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/domain/admin/v0/enterprise_sequencer_administration_service.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/domain/admin/v0/enterprise_sequencer_administration_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import sequencer_initialization_snapshot_pb2 as com_dot_digitalasset_dot_canton_dot_domain_dot_admin_dot_v0_dot_sequencer__initialization__snapshot__pb2
from ....pruning.admin.v0 import pruning_pb2 as com_dot_digitalasset_dot_canton_dot_pruning_dot_admin_dot_v0_dot_pruning__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nYcom/digitalasset/canton/domain/admin/v0/enterprise_sequencer_administration_service.proto\x12\'com.digitalasset.canton.domain.admin.v0\x1aOcom/digitalasset/canton/domain/admin/v0/sequencer_initialization_snapshot.proto\x1a\x36\x63om/digitalasset/canton/pruning/admin/v0/pruning.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"+\n\x0f\x45thereumAccount\x12\x18\n\x07\x61\x64\x64ress\x18\x01 \x01(\tR\x07\x61\x64\x64ress\"\xf5\x03\n\x0eLedgerIdentity\x12\x65\n\x10\x65thereum_account\x18\x01 \x01(\x0b\x32\x38.com.digitalasset.canton.domain.admin.v0.EthereumAccountH\x00R\x0f\x65thereumAccount\x1ag\n\x10\x41uthorizeRequest\x12S\n\x08identify\x18\x01 \x01(\x0b\x32\x37.com.digitalasset.canton.domain.admin.v0.LedgerIdentityR\x08identify\x1a\xd6\x01\n\x11\x41uthorizeResponse\x12[\n\x07success\x18\x01 \x01(\x0b\x32?.com.digitalasset.canton.domain.admin.v0.LedgerIdentity.SuccessH\x00R\x07success\x12[\n\x07\x66\x61ilure\x18\x02 \x01(\x0b\x32?.com.digitalasset.canton.domain.admin.v0.LedgerIdentity.FailureH\x00R\x07\x66\x61ilureB\x07\n\x05value\x1a\t\n\x07Success\x1a!\n\x07\x46\x61ilure\x12\x16\n\x06reason\x18\x01 \x01(\tR\x06reasonB\x0c\n\nidentifier\"t\n\x07Pruning\x1a\x43\n\x07Request\x12\x38\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimestamp\x1a$\n\x08Response\x12\x18\n\x07\x64\x65tails\x18\x01 \x01(\tR\x07\x64\x65tails\"\xb5\x04\n\x08Snapshot\x1a\x43\n\x07Request\x12\x38\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimestamp\x1a\xb3\x02\n\x08Response\x12U\n\x07success\x18\x01 \x01(\x0b\x32\x39.com.digitalasset.canton.domain.admin.v0.Snapshot.SuccessH\x00R\x07success\x12U\n\x07\x66\x61ilure\x18\x02 \x01(\x0b\x32\x39.com.digitalasset.canton.domain.admin.v0.Snapshot.FailureH\x00R\x07\x66\x61ilure\x12p\n\x10versionedSuccess\x18\x03 \x01(\x0b\x32\x42.com.digitalasset.canton.domain.admin.v0.Snapshot.VersionedSuccessH\x00R\x10versionedSuccessB\x07\n\x05value\x1a[\n\x07Success\x12P\n\x05state\x18\x01 \x01(\x0b\x32:.com.digitalasset.canton.domain.admin.v0.SequencerSnapshotR\x05state\x1a!\n\x07\x46\x61ilure\x12\x16\n\x06reason\x18\x01 \x01(\tR\x06reason\x1a.\n\x10VersionedSuccess\x12\x1a\n\x08snapshot\x18\x01 \x01(\x0cR\x08snapshot\".\n\x14\x44isableMemberRequest\x12\x16\n\x06member\x18\x01 \x01(\tR\x06member2\xd5\x0c\n(EnterpriseSequencerAdministrationService\x12|\n\x05Prune\x12\x38.com.digitalasset.canton.domain.admin.v0.Pruning.Request\x1a\x39.com.digitalasset.canton.domain.admin.v0.Pruning.Response\x12\x81\x01\n\x08Snapshot\x12\x39.com.digitalasset.canton.domain.admin.v0.Snapshot.Request\x1a:.com.digitalasset.canton.domain.admin.v0.Snapshot.Response\x12\x66\n\rDisableMember\x12=.com.digitalasset.canton.domain.admin.v0.DisableMemberRequest\x1a\x16.google.protobuf.Empty\x12\xae\x01\n\x17\x41uthorizeLedgerIdentity\x12H.com.digitalasset.canton.domain.admin.v0.LedgerIdentity.AuthorizeRequest\x1aI.com.digitalasset.canton.domain.admin.v0.LedgerIdentity.AuthorizeResponse\x12\x8c\x01\n\x0bSetSchedule\x12=.com.digitalasset.canton.pruning.admin.v0.SetSchedule.Request\x1a>.com.digitalasset.canton.pruning.admin.v0.SetSchedule.Response\x12\x80\x01\n\x07SetCron\x12\x39.com.digitalasset.canton.pruning.admin.v0.SetCron.Request\x1a:.com.digitalasset.canton.pruning.admin.v0.SetCron.Response\x12\x95\x01\n\x0eSetMaxDuration\x12@.com.digitalasset.canton.pruning.admin.v0.SetMaxDuration.Request\x1a\x41.com.digitalasset.canton.pruning.admin.v0.SetMaxDuration.Response\x12\x8f\x01\n\x0cSetRetention\x12>.com.digitalasset.canton.pruning.admin.v0.SetRetention.Request\x1a?.com.digitalasset.canton.pruning.admin.v0.SetRetention.Response\x12\x92\x01\n\rClearSchedule\x12?.com.digitalasset.canton.pruning.admin.v0.ClearSchedule.Request\x1a@.com.digitalasset.canton.pruning.admin.v0.ClearSchedule.Response\x12\x8c\x01\n\x0bGetSchedule\x12=.com.digitalasset.canton.pruning.admin.v0.GetSchedule.Request\x1a>.com.digitalasset.canton.pruning.admin.v0.GetSchedule.Response\x12\xad\x01\n\x16LocatePruningTimestamp\x12H.com.digitalasset.canton.pruning.admin.v0.LocatePruningTimestamp.Request\x1aI.com.digitalasset.canton.pruning.admin.v0.LocatePruningTimestamp.ResponseBXZVgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/domain/admin/v0b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.domain.admin.v0.enterprise_sequencer_administration_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZVgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/domain/admin/v0'
  _globals['_ETHEREUMACCOUNT']._serialized_start=333
  _globals['_ETHEREUMACCOUNT']._serialized_end=376
  _globals['_LEDGERIDENTITY']._serialized_start=379
  _globals['_LEDGERIDENTITY']._serialized_end=880
  _globals['_LEDGERIDENTITY_AUTHORIZEREQUEST']._serialized_start=500
  _globals['_LEDGERIDENTITY_AUTHORIZEREQUEST']._serialized_end=603
  _globals['_LEDGERIDENTITY_AUTHORIZERESPONSE']._serialized_start=606
  _globals['_LEDGERIDENTITY_AUTHORIZERESPONSE']._serialized_end=820
  _globals['_LEDGERIDENTITY_SUCCESS']._serialized_start=822
  _globals['_LEDGERIDENTITY_SUCCESS']._serialized_end=831
  _globals['_LEDGERIDENTITY_FAILURE']._serialized_start=833
  _globals['_LEDGERIDENTITY_FAILURE']._serialized_end=866
  _globals['_PRUNING']._serialized_start=882
  _globals['_PRUNING']._serialized_end=998
  _globals['_PRUNING_REQUEST']._serialized_start=893
  _globals['_PRUNING_REQUEST']._serialized_end=960
  _globals['_PRUNING_RESPONSE']._serialized_start=962
  _globals['_PRUNING_RESPONSE']._serialized_end=998
  _globals['_SNAPSHOT']._serialized_start=1001
  _globals['_SNAPSHOT']._serialized_end=1566
  _globals['_SNAPSHOT_REQUEST']._serialized_start=893
  _globals['_SNAPSHOT_REQUEST']._serialized_end=960
  _globals['_SNAPSHOT_RESPONSE']._serialized_start=1083
  _globals['_SNAPSHOT_RESPONSE']._serialized_end=1390
  _globals['_SNAPSHOT_SUCCESS']._serialized_start=1392
  _globals['_SNAPSHOT_SUCCESS']._serialized_end=1483
  _globals['_SNAPSHOT_FAILURE']._serialized_start=833
  _globals['_SNAPSHOT_FAILURE']._serialized_end=866
  _globals['_SNAPSHOT_VERSIONEDSUCCESS']._serialized_start=1520
  _globals['_SNAPSHOT_VERSIONEDSUCCESS']._serialized_end=1566
  _globals['_DISABLEMEMBERREQUEST']._serialized_start=1568
  _globals['_DISABLEMEMBERREQUEST']._serialized_end=1614
  _globals['_ENTERPRISESEQUENCERADMINISTRATIONSERVICE']._serialized_start=1617
  _globals['_ENTERPRISESEQUENCERADMINISTRATIONSERVICE']._serialized_end=3238
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/domain/api/v0/domain_service.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/domain/api/v0/domain_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import service_agreement_pb2 as com_dot_digitalasset_dot_canton_dot_domain_dot_api_dot_v0_dot_service__agreement__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:com/digitalasset/canton/domain/api/v0/domain_service.proto\x12%com.digitalasset.canton.domain.api.v0\x1a=com/digitalasset/canton/domain/api/v0/service_agreement.proto2\xb3\x01\n\rDomainService\x12\x9c\x01\n\x13GetServiceAgreement\x12\x41.com.digitalasset.canton.domain.api.v0.GetServiceAgreementRequest\x1a\x42.com.digitalasset.canton.domain.api.v0.GetServiceAgreementResponse\x1a\x03\x88\x02\x01\x42VZTgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/domain/api/v0b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.domain.api.v0.domain_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZTgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/domain/api/v0'
  _globals['_DOMAINSERVICE']._loaded_options = None
  _globals['_DOMAINSERVICE']._serialized_options = b'\210\002\001'
  _globals['_DOMAINSERVICE']._serialized_start=165
  _globals['_DOMAINSERVICE']._serialized_end=344
# @@protoc_insertion_point(module_scope)
